@@ -20,7 +20,7 @@ import (
 	"net"
 	"time"
 
-	"github.com/blang/semver"
+	"github.com/blang/semver/v4"
 )
 
 // Profile represents a minikube profile
