@@ -34,6 +34,7 @@ func TestDownload(t *testing.T) {
 	t.Run("ImageToDaemon", testImageToDaemon)
 	t.Run("PreloadNotExists", testPreloadNotExists)
 	t.Run("PreloadChecksumMismatch", testPreloadChecksumMismatch)
+	t.Run("PreloadExistsCaching", testPreloadExistsCaching)
 }
 
 // Returns a mock function that sleeps before incrementing `downloadsCounter` and creates the requested file.
@@ -197,3 +198,42 @@ func testImageToDaemon(t *testing.T) {
 		t.Errorf("Expected only 1 download attempt but got %v!", downloadNum)
 	}
 }
+
+// Validates that preload existence checks correctly caches values retrieved by remote checks.
+func testPreloadExistsCaching(t *testing.T) {
+	checkCache = func(file string) (fs.FileInfo, error) {
+		return nil, fmt.Errorf("cache not found")
+	}
+	doesPreloadExist := false
+	checkCalled := false
+	checkRemotePreloadExists = func(k8sVersion, containerRuntime string) bool {
+		checkCalled = true
+		setPreloadState(k8sVersion, containerRuntime, doesPreloadExist)
+		return doesPreloadExist
+	}
+	existence := PreloadExists("v1", "c1", "docker", true)
+	if existence || !checkCalled {
+		t.Errorf("Expected preload not to exist and a check to be performed. Existence: %v, Check: %v", existence, checkCalled)
+	}
+	checkCalled = false
+	existence = PreloadExists("v1", "c1", "docker", true)
+	if existence || checkCalled {
+		t.Errorf("Expected preload not to exist and no check to be performed. Existence: %v, Check: %v", existence, checkCalled)
+	}
+	doesPreloadExist = true
+	checkCalled = false
+	existence = PreloadExists("v2", "c1", "docker", true)
+	if !existence || !checkCalled {
+		t.Errorf("Expected preload to exist and a check to be performed. Existence: %v, Check: %v", existence, checkCalled)
+	}
+	checkCalled = false
+	existence = PreloadExists("v2", "c2", "docker", true)
+	if !existence || !checkCalled {
+		t.Errorf("Expected preload to exist and a check to be performed. Existence: %v, Check: %v", existence, checkCalled)
+	}
+	checkCalled = false
+	existence = PreloadExists("v2", "c2", "docker", true)
+	if !existence || checkCalled {
+		t.Errorf("Expected preload to exist and no check to be performed. Existence: %v, Check: %v", existence, checkCalled)
+	}
+}
