@@ -117,9 +117,11 @@ func (s *OpenRC) Disable(svc string) error {
 	return nil
 }
 
-// DisableNow not implemented for openRC
+// DisableNow does Disable + Stop
 func (s *OpenRC) DisableNow(svc string) error {
-	return fmt.Errorf("disable now is not implemented for OpenRC! PRs to fix are welcomed")
+	// supposed to do disable + stop
+	// disable does nothing for OpenRC, so just Stop here
+	return s.Stop(svc)
 }
 
 // Mask does nothing
@@ -132,9 +134,11 @@ func (s *OpenRC) Enable(svc string) error {
 	return nil
 }
 
-// EnableNow  not implemented for openRC
+// EnableNow does Enable + Start
 func (s *OpenRC) EnableNow(svc string) error {
-	return fmt.Errorf("enable now is not implemented for OpenRC! PRs to fix are welcomed")
+	// supposed to do enable + start
+	// enable does nothing for OpenRC, so just Start here
+	return s.Start(svc)
 }
 
 // Unmask does nothing
