@@ -45,6 +45,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/reason"
 	"k8s.io/minikube/pkg/util/retry"
 
+	"github.com/blang/semver/v4"
 	"github.com/elazarl/goproxy"
 	"github.com/hashicorp/go-retryablehttp"
 	"github.com/otiai10/copy"
@@ -59,6 +60,11 @@ type validateFunc func(context.Context, *testing.T, string)
 // used in validateStartWithProxy and validateSoftStart
 var apiPortTest = 8441
 
+// Store the proxy session so we can clean it up at the end
+var mitm *StartSession
+
+var runCorpProxy = GithubActionRunner() && runtime.GOOS == "linux" && !arm64Platform()
+
 // TestFunctional are functionality tests which can safely share a profile in parallel
 func TestFunctional(t *testing.T) {
 
@@ -99,13 +105,22 @@ func TestFunctional(t *testing.T) {
 			if ctx.Err() == context.DeadlineExceeded {
 				t.Fatalf("Unable to run more tests (deadline exceeded)")
 			}
+			if tc.name == "StartWithProxy" && runCorpProxy {
+				tc.name = "StartWithCustomCerts"
+				tc.validator = validateStartWithCustomCerts
+			}
 			t.Run(tc.name, func(t *testing.T) {
 				tc.validator(ctx, t, profile)
 			})
 		}
 	})
 
-	defer cleanupUnwantedImages(ctx, t, profile)
+	defer func() {
+		cleanupUnwantedImages(ctx, t, profile)
+		if runCorpProxy {
+			mitm.Stop(t)
+		}
+	}()
 
 	// Parallelized tests
 	t.Run("parallel", func(t *testing.T) {
@@ -116,6 +131,7 @@ func TestFunctional(t *testing.T) {
 			{"ConfigCmd", validateConfigCmd},
 			{"DashboardCmd", validateDashboardCmd},
 			{"DryRun", validateDryRun},
+			{"InternationalLanguage", validateInternationalLanguage},
 			{"StatusCmd", validateStatusCmd},
 			{"LogsCmd", validateLogsCmd},
 			{"LogsFileCmd", validateLogsFileCmd},
@@ -139,6 +155,7 @@ func TestFunctional(t *testing.T) {
 			{"BuildImage", validateBuildImage},
 			{"ListImages", validateListImages},
 			{"NonActiveRuntimeDisabled", validateNotActiveRuntimeDisabled},
+			{"Version", validateVersionCmd},
 		}
 		for _, tc := range tests {
 			tc := tc
@@ -520,40 +537,26 @@ func validatePodmanEnv(ctx context.Context, t *testing.T, profile string) {
 // validateStartWithProxy makes sure minikube start respects the HTTP_PROXY environment variable
 func validateStartWithProxy(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
-
 	srv, err := startHTTPProxy(t)
 	if err != nil {
 		t.Fatalf("failed to set up the test proxy: %s", err)
 	}
 
-	// Use more memory so that we may reliably fit MySQL and nginx
-	memoryFlag := "--memory=4000"
-	// to avoid failure for mysq/pv on virtualbox on darwin on free github actions,
-	if GithubActionRunner() && VirtualboxDriver() {
-		memoryFlag = "--memory=6000"
-	}
-	// passing --api-server-port so later verify it didn't change in soft start.
-	startArgs := append([]string{"start", "-p", profile, memoryFlag, fmt.Sprintf("--apiserver-port=%d", apiPortTest), "--wait=all"}, StartArgs()...)
-	c := exec.CommandContext(ctx, Target(), startArgs...)
-	env := os.Environ()
-	env = append(env, fmt.Sprintf("HTTP_PROXY=%s", srv.Addr))
-	env = append(env, "NO_PROXY=")
-	c.Env = env
-	rr, err := Run(t, c)
+	startMinikubeWithProxy(ctx, t, profile, "HTTP_PROXY", srv.Addr)
+}
+
+// validateStartWithCustomCerts makes sure minikube start respects the HTTPS_PROXY environment variable and works with custom certs
+// a proxy is started by calling the mitmdump binary in the background, then installing the certs generated by the binary
+// mitmproxy/dump creates the proxy at localhost at port 8080
+// only runs on Github Actions for amd64 linux, otherwise validateStartWithProxy runs instead
+func validateStartWithCustomCerts(ctx context.Context, t *testing.T, profile string) {
+	defer PostMortemLogs(t, profile)
+	err := startProxyWithCustomCerts(ctx, t)
 	if err != nil {
-		t.Errorf("failed minikube start. args %q: %v", rr.Command(), err)
-	}
-
-	want := "Found network options:"
-	if !strings.Contains(rr.Stdout.String(), want) {
-		t.Errorf("start stdout=%s, want: *%s*", rr.Stdout.String(), want)
-	}
-
-	want = "You appear to be using a proxy"
-	if !strings.Contains(rr.Stderr.String(), want) {
-		t.Errorf("start stderr=%s, want: *%s*", rr.Stderr.String(), want)
+		t.Fatalf("failed to set up the test proxy: %s", err)
 	}
 
+	startMinikubeWithProxy(ctx, t, profile, "HTTPS_PROXY", "127.0.0.1:8080")
 }
 
 // validateAuditAfterStart makes sure the audit log contains the correct logging after minikube start
@@ -644,7 +647,11 @@ func validateMinikubeKubectl(ctx context.Context, t *testing.T, profile string)
 func validateMinikubeKubectlDirectCall(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
 	dir := filepath.Dir(Target())
-	dstfn := filepath.Join(dir, "kubectl")
+	newName := "kubectl"
+	if runtime.GOOS == "windows" {
+		newName += ".exe"
+	}
+	dstfn := filepath.Join(dir, newName)
 	err := os.Link(Target(), dstfn)
 
 	if err != nil {
@@ -897,6 +904,32 @@ func validateDryRun(ctx context.Context, t *testing.T, profile string) {
 	}
 }
 
+// validateInternationalLanguage asserts that the language used can be changed with environment variables
+func validateInternationalLanguage(ctx context.Context, t *testing.T, profile string) {
+	// dry-run mode should always be able to finish quickly (<5s)
+	mctx, cancel := context.WithTimeout(ctx, Seconds(5))
+	defer cancel()
+
+	// Too little memory!
+	startArgs := append([]string{"start", "-p", profile, "--dry-run", "--memory", "250MB", "--alsologtostderr"}, StartArgs()...)
+	c := exec.CommandContext(mctx, Target(), startArgs...)
+	c.Env = append(os.Environ(), "LC_ALL=fr")
+
+	rr, err := Run(t, c)
+
+	wantCode := reason.ExInsufficientMemory
+	if rr.ExitCode != wantCode {
+		if HyperVDriver() {
+			t.Skip("skipping this error on HyperV till this issue is solved https://github.com/kubernetes/minikube/issues/9785")
+		} else {
+			t.Errorf("dry-run(250MB) exit code = %d, wanted = %d: %v", rr.ExitCode, wantCode, err)
+		}
+	}
+	if !strings.Contains(rr.Stdout.String(), "Utilisation du pilote") {
+		t.Errorf("dry-run output was expected to be in French. Expected \"Utilisation du pilote\", but not present in output:\n%s", rr.Stdout.String())
+	}
+}
+
 // validateCacheCmd tests functionality of cache command (cache add, delete, list)
 func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
@@ -1443,59 +1476,6 @@ func validateSSHCmd(ctx context.Context, t *testing.T, profile string) {
 	}
 }
 
-// cpTestMinikubePath is where the test file will be located in the Minikube instance
-func cpTestMinikubePath() string {
-	return "/home/docker/cp-test.txt"
-}
-
-// cpTestLocalPath is where the test file located in host os
-func cpTestLocalPath() string {
-	return filepath.Join(*testdataDir, "cp-test.txt")
-}
-
-func testCpCmd(ctx context.Context, t *testing.T, profile string, node string) {
-	srcPath := cpTestLocalPath()
-	dstPath := cpTestMinikubePath()
-
-	cpArgv := []string{"-p", profile, "cp", srcPath}
-	if node == "" {
-		cpArgv = append(cpArgv, dstPath)
-	} else {
-		cpArgv = append(cpArgv, fmt.Sprintf("%s:%s", node, dstPath))
-	}
-
-	rr, err := Run(t, exec.CommandContext(ctx, Target(), cpArgv...))
-	if ctx.Err() == context.DeadlineExceeded {
-		t.Errorf("failed to run command by deadline. exceeded timeout : %s", rr.Command())
-	}
-	if err != nil {
-		t.Errorf("failed to run an cp command. args %q : %v", rr.Command(), err)
-	}
-
-	sshArgv := []string{"-p", profile, "ssh"}
-	if node != "" {
-		sshArgv = append(sshArgv, "-n", node)
-	}
-	sshArgv = append(sshArgv, fmt.Sprintf("sudo cat %s", dstPath))
-
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), sshArgv...))
-	if ctx.Err() == context.DeadlineExceeded {
-		t.Errorf("failed to run command by deadline. exceeded timeout : %s", rr.Command())
-	}
-	if err != nil {
-		t.Errorf("failed to run an cp command. args %q : %v", rr.Command(), err)
-	}
-
-	expected, err := ioutil.ReadFile(srcPath)
-	if err != nil {
-		t.Errorf("failed to read test file 'testdata/cp-test.txt' : %v", err)
-	}
-
-	if diff := cmp.Diff(string(expected), rr.Stdout.String()); diff != "" {
-		t.Errorf("/testdata/cp-test.txt content mismatch (-want +got):\n%s", diff)
-	}
-}
-
 // validateCpCmd asserts basic "cp" command functionality
 func validateCpCmd(ctx context.Context, t *testing.T, profile string) {
 	if NoneDriver() {
@@ -1762,7 +1742,6 @@ users:
 				if err := ioutil.WriteFile(tf.Name(), tc.kubeconfig, 0644); err != nil {
 					t.Fatal(err)
 				}
-
 				t.Cleanup(func() {
 					os.Remove(tf.Name())
 				})
@@ -1782,6 +1761,79 @@ users:
 	}
 }
 
+// startProxyWithCustomCerts mimics starts a proxy with custom certs by using mitmproxy and installing its certs
+func startProxyWithCustomCerts(ctx context.Context, t *testing.T) error {
+	// Download the mitmproxy bundle for mitmdump
+	_, err := Run(t, exec.CommandContext(ctx, "curl", "-LO", "https://snapshots.mitmproxy.org/6.0.2/mitmproxy-6.0.2-linux.tar.gz"))
+	if err != nil {
+		return errors.Wrap(err, "download mitmproxy tar")
+	}
+	defer func() {
+		err := os.Remove("mitmproxy-6.0.2-linux.tar.gz")
+		if err != nil {
+			t.Logf("remove tarball: %v", err)
+		}
+	}()
+
+	mitmDir, err := ioutil.TempDir("", "")
+	if err != nil {
+		return errors.Wrap(err, "create temp dir")
+	}
+
+	_, err = Run(t, exec.CommandContext(ctx, "tar", "xzf", "mitmproxy-6.0.2-linux.tar.gz", "-C", mitmDir))
+	if err != nil {
+		return errors.Wrap(err, "untar mitmproxy tar")
+	}
+
+	// Start mitmdump in the background, this will create the needed certs
+	// and provide the necessary proxy at 127.0.0.1:8080
+	mitmRR, err := Start(t, exec.CommandContext(ctx, path.Join(mitmDir, "mitmdump"), "--set", fmt.Sprintf("confdir=%s", mitmDir)))
+	if err != nil {
+		return errors.Wrap(err, "starting mitmproxy")
+	}
+
+	// Store it for cleanup later
+	mitm = mitmRR
+
+	// Add a symlink from the cert to the correct directory
+	certFile := path.Join(mitmDir, "mitmproxy-ca-cert.pem")
+	// wait 15 seconds for the certs to show up
+	_, err = os.Stat(certFile)
+	tries := 1
+	for os.IsNotExist(err) {
+		time.Sleep(1 * time.Second)
+		tries++
+		if tries > 15 {
+			break
+		}
+		_, err = os.Stat(certFile)
+	}
+	if os.IsNotExist(err) {
+		return errors.Wrap(err, "cert files never showed up")
+	}
+
+	destCertPath := path.Join("/etc/ssl/certs", "mitmproxy-ca-cert.pem")
+	symLinkCmd := fmt.Sprintf("ln -fs %s %s", certFile, destCertPath)
+	if _, err := Run(t, exec.CommandContext(ctx, "sudo", "/bin/bash", "-c", symLinkCmd)); err != nil {
+		return errors.Wrap(err, "cert symlink")
+	}
+
+	// Add a symlink of the form {hash}.0
+	rr, err := Run(t, exec.CommandContext(ctx, "openssl", "x509", "-hash", "-noout", "-in", certFile))
+	if err != nil {
+		return errors.Wrap(err, "cert hashing")
+	}
+	stringHash := strings.TrimSpace(rr.Stdout.String())
+	hashLink := path.Join("/etc/ssl/certs", fmt.Sprintf("%s.0", stringHash))
+
+	hashCmd := fmt.Sprintf("test -L %s || ln -fs %s %s", hashLink, destCertPath, hashLink)
+	if _, err := Run(t, exec.CommandContext(ctx, "sudo", "/bin/bash", "-c", hashCmd)); err != nil {
+		return errors.Wrap(err, "cert hash symlink")
+	}
+
+	return nil
+}
+
 // startHTTPProxy runs a local http proxy and sets the env vars for it.
 func startHTTPProxy(t *testing.T) (*http.Server, error) {
 	port, err := freeport.GetFreePort()
@@ -1799,3 +1851,66 @@ func startHTTPProxy(t *testing.T) (*http.Server, error) {
 	}(srv, t)
 	return srv, nil
 }
+
+func startMinikubeWithProxy(ctx context.Context, t *testing.T, profile string, proxyEnv string, addr string) {
+	// Use more memory so that we may reliably fit MySQL and nginx
+	memoryFlag := "--memory=4000"
+	// to avoid failure for mysq/pv on virtualbox on darwin on free github actions,
+	if GithubActionRunner() && VirtualboxDriver() {
+		memoryFlag = "--memory=6000"
+	}
+	// passing --api-server-port so later verify it didn't change in soft start.
+	startArgs := append([]string{"start", "-p", profile, memoryFlag, fmt.Sprintf("--apiserver-port=%d", apiPortTest), "--wait=all"}, StartArgs()...)
+	c := exec.CommandContext(ctx, Target(), startArgs...)
+	env := os.Environ()
+	env = append(env, fmt.Sprintf("%s=%s", proxyEnv, addr))
+	env = append(env, "NO_PROXY=")
+	c.Env = env
+	rr, err := Run(t, c)
+	if err != nil {
+		t.Errorf("failed minikube start. args %q: %v", rr.Command(), err)
+	}
+
+	want := "Found network options:"
+	if !strings.Contains(rr.Stdout.String(), want) {
+		t.Errorf("start stdout=%s, want: *%s*", rr.Stdout.String(), want)
+	}
+
+	want = "You appear to be using a proxy"
+	if !strings.Contains(rr.Stderr.String(), want) {
+		t.Errorf("start stderr=%s, want: *%s*", rr.Stderr.String(), want)
+	}
+}
+
+// validateVersionCmd asserts `minikube version` command works fine for both --short and --components
+func validateVersionCmd(ctx context.Context, t *testing.T, profile string) {
+
+	t.Run("short", func(t *testing.T) {
+		MaybeParallel(t)
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "version", "--short"))
+		if err != nil {
+			t.Errorf("failed to get version --short: %v", err)
+		}
+
+		_, err = semver.Make(strings.TrimSpace(strings.Trim(rr.Stdout.String(), "v")))
+		if err != nil {
+			t.Errorf("failed to get a valid semver for minikube version --short:%s %v", rr.Output(), err)
+		}
+	})
+
+	t.Run("components", func(t *testing.T) {
+		MaybeParallel(t)
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "version", "-o=json", "--components"))
+		if err != nil {
+			t.Errorf("error version: %v", err)
+		}
+		got := rr.Stdout.String()
+		for _, c := range []string{"buildctl", "commit", "containerd", "crictl", "crio", "ctr", "docker", "minikubeVersion", "podman", "run"} {
+			if !strings.Contains(got, c) {
+				t.Errorf("expected to see %q in the minikube version --components but got:\n%s", c, got)
+			}
+
+		}
+	})
+
+}
